Text Input
==========

The text input widget is a simple input field for user entry of text data.

Usage
-----

.. code-block:: Python

    import toga

    input = toga.TextInput(placeholder='enter name here')


Supported Platforms
-------------------

.. include:: ../supported_platforms/TextInput.rst

Reference
---------

.. autoclass:: toga.interface.widgets.textinput.TextInput
   :members:
   :undoc-members:
   :inherited-members: